Package: constructive
Title: Display Idiomatic Code to Construct Most R Objects
Version: 1.3.0
Authors@R: c(
    person("Antoine", "Fabri", , "antoine.fabri@gmail.com", role = c("aut", "cre")),
    person("Kirill", "Müller", , "kirill@cynkra.com", role = "ctb",
           comment = c(ORCID = "0000-0002-1416-3412")),
    person("Jacob", "Scott", , "jscott2718@gmail.com", role = "ctb"),
    person("cynkra GmbH", , , "mail@cynkra.com", role = "fnd",
           comment = c(ROR = "0335t7e62"))
  )
Description: Prints code that can be used to recreate R objects. In a
    sense it is similar to 'base::dput()' or 'base::deparse()' but
    'constructive' strives to use idiomatic constructors.
License: MIT + file LICENSE
URL: https://github.com/cynkra/constructive,
        https://cynkra.github.io/constructive/
BugReports: https://github.com/cynkra/constructive/issues
Imports: cli (>= 3.1.0), diffobj, methods, rlang (>= 1.0.0), waldo
Suggests: bit64, blob, clipr, data.table, DiagrammeR, DiagrammeRsvg,
        dm, dplyr, ellmer, forcats, ggplot2, jsonlite, knitr,
        lubridate, pixarfilms, R6, reprex, rmarkdown, roxygen2,
        rstudioapi, S7, scales, sf, testthat (>= 3.0.0), tibble,
        tidyselect, vctrs, withr, xml2, xts, zoo
VignetteBuilder: knitr
Config/Needs/website: cynkra/cynkratemplate
Config/testthat/edition: 3
Encoding: UTF-8
RoxygenNote: 7.3.3.9000
NeedsCompilation: yes
Packaged: 2025-09-19 13:40:45 UTC; Antoine
Author: Antoine Fabri [aut, cre],
  Kirill Müller [ctb] (ORCID: <https://orcid.org/0000-0002-1416-3412>),
  Jacob Scott [ctb],
  cynkra GmbH [fnd] (ROR: <https://ror.org/0335t7e62>)
Maintainer: Antoine Fabri <antoine.fabri@gmail.com>
Repository: CRAN
Date/Publication: 2025-09-19 14:00:10 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-26 00:16:42 UTC; unix
Archs: constructive.so.dSYM
