# Generated by roxygen2: do not edit by hand

S3method(".cstr_construct.ggplot2::element_blank",element_blank)
S3method(".cstr_construct.ggplot2::element_geom",element_geom)
S3method(".cstr_construct.ggplot2::element_line",element_line)
S3method(".cstr_construct.ggplot2::element_point",element_point)
S3method(".cstr_construct.ggplot2::element_polygon",element_polygon)
S3method(".cstr_construct.ggplot2::element_rect",element_rect)
S3method(".cstr_construct.ggplot2::element_text",element_text)
S3method(".cstr_construct.ggplot2::ggplot",ggplot)
S3method(".cstr_construct.ggplot2::ggplot",list)
S3method(".cstr_construct.ggplot2::margin",double)
S3method(".cstr_construct.ggplot2::margin",margin)
S3method(".cstr_construct.ggplot2::theme",list)
S3method(".cstr_construct.ggplot2::theme",theme)
S3method(.cstr_construct,"NULL")
S3method(.cstr_construct,"S7_union.|")
S3method(.cstr_construct,"ellmer::TypeArray.TypeArray")
S3method(.cstr_construct,"ellmer::TypeArray.type_array")
S3method(.cstr_construct,"ellmer::TypeBasic.TypeBasic")
S3method(.cstr_construct,"ellmer::TypeBasic.default")
S3method(.cstr_construct,"ellmer::TypeEnum.TypeEnum")
S3method(.cstr_construct,"ellmer::TypeEnum.type_enum")
S3method(.cstr_construct,"ellmer::TypeJsonSchema.TypeJsonSchema")
S3method(.cstr_construct,"ellmer::TypeJsonSchema.type_from_schema")
S3method(.cstr_construct,"ellmer::TypeObject.TypeObject")
S3method(.cstr_construct,"ellmer::TypeObject.type_object")
S3method(.cstr_construct,"function")
S3method(.cstr_construct,"ggplot2::element_blank")
S3method(.cstr_construct,"ggplot2::element_geom")
S3method(.cstr_construct,"ggplot2::element_line")
S3method(.cstr_construct,"ggplot2::element_point")
S3method(.cstr_construct,"ggplot2::element_polygon")
S3method(.cstr_construct,"ggplot2::element_rect")
S3method(.cstr_construct,"ggplot2::element_text")
S3method(.cstr_construct,"ggplot2::ggplot")
S3method(.cstr_construct,"ggplot2::labels.labs")
S3method(.cstr_construct,"ggplot2::mapping")
S3method(.cstr_construct,"ggplot2::margin")
S3method(.cstr_construct,"ggplot2::theme")
S3method(.cstr_construct,AsIs)
S3method(.cstr_construct,CoordCartesian)
S3method(.cstr_construct,CoordFixed)
S3method(.cstr_construct,CoordFlip)
S3method(.cstr_construct,CoordMap)
S3method(.cstr_construct,CoordMunch)
S3method(.cstr_construct,CoordPolar)
S3method(.cstr_construct,CoordQuickmap)
S3method(.cstr_construct,CoordRadial.coord_radial)
S3method(.cstr_construct,CoordSf)
S3method(.cstr_construct,CoordTrans)
S3method(.cstr_construct,CoordTransform.coord_transform)
S3method(.cstr_construct,Date)
S3method(.cstr_construct,FacetGrid)
S3method(.cstr_construct,FacetNull.facet_null)
S3method(.cstr_construct,FacetWrap)
S3method(.cstr_construct,Guide)
S3method(.cstr_construct,GuideAxis.guide_axis)
S3method(.cstr_construct,GuideAxisLogticks.guide_axis_logticks)
S3method(.cstr_construct,GuideAxisStack.guide_axis_stack)
S3method(.cstr_construct,GuideAxisTheta.guide_axis_theta)
S3method(.cstr_construct,GuideBins.guide_bins)
S3method(.cstr_construct,GuideColourbar.guide_colorbar)
S3method(.cstr_construct,GuideColoursteps.guide_colorsteps)
S3method(.cstr_construct,GuideCustom.guide_custom)
S3method(.cstr_construct,GuideLegend.guide_legend)
S3method(.cstr_construct,GuideNone.guide_none)
S3method(.cstr_construct,Guides.guides)
S3method(.cstr_construct,Layer)
S3method(.cstr_construct,POSIXct)
S3method(.cstr_construct,POSIXlt)
S3method(.cstr_construct,R6.R6Class)
S3method(.cstr_construct,R6ClassGenerator.R6Class)
S3method(.cstr_construct,R_system_version)
S3method(.cstr_construct,S4)
S3method(.cstr_construct,S4.prototype)
S3method(.cstr_construct,S7_S3_class.new_S3_class)
S3method(.cstr_construct,S7_any.class_any)
S3method(.cstr_construct,S7_base_class.S7)
S3method(.cstr_construct,S7_class.new_class)
S3method(.cstr_construct,S7_external_generic.new_external_generic)
S3method(.cstr_construct,S7_generic.new_generic)
S3method(.cstr_construct,S7_object.S7_object)
S3method(.cstr_construct,S7_object.new_class)
S3method(.cstr_construct,S7_property.new_property)
S3method(.cstr_construct,S7_union.default)
S3method(.cstr_construct,S7_union.new_union)
S3method(.cstr_construct,Scale)
S3method(.cstr_construct,ScalesList)
S3method(.cstr_construct,array)
S3method(.cstr_construct,bibentry)
S3method(.cstr_construct,blob)
S3method(.cstr_construct,character)
S3method(.cstr_construct,citationFooter)
S3method(.cstr_construct,citationHeader)
S3method(.cstr_construct,classGeneratorFunction)
S3method(.cstr_construct,classPrototypeDef)
S3method(.cstr_construct,classRepresentation)
S3method(.cstr_construct,complex)
S3method(.cstr_construct,constructive_options)
S3method(.cstr_construct,data.frame)
S3method(.cstr_construct,data.table)
S3method(.cstr_construct,default)
S3method(.cstr_construct,difftime)
S3method(.cstr_construct,dm)
S3method(.cstr_construct,dots)
S3method(.cstr_construct,double)
S3method(.cstr_construct,element_blank)
S3method(.cstr_construct,element_grob)
S3method(.cstr_construct,element_line)
S3method(.cstr_construct,element_rect)
S3method(.cstr_construct,element_render)
S3method(.cstr_construct,element_text)
S3method(.cstr_construct,environment)
S3method(.cstr_construct,error)
S3method(.cstr_construct,expression)
S3method(.cstr_construct,externalptr)
S3method(.cstr_construct,factor)
S3method(.cstr_construct,formula)
S3method(.cstr_construct,ggplot)
S3method(.cstr_construct,ggproto)
S3method(.cstr_construct,grouped_df)
S3method(.cstr_construct,hexmode)
S3method(.cstr_construct,integer)
S3method(.cstr_construct,integer64)
S3method(.cstr_construct,labels)
S3method(.cstr_construct,language)
S3method(.cstr_construct,list)
S3method(.cstr_construct,logical)
S3method(.cstr_construct,margin)
S3method(.cstr_construct,matrix)
S3method(.cstr_construct,mts)
S3method(.cstr_construct,noquote)
S3method(.cstr_construct,numeric_version)
S3method(.cstr_construct,object.S7_object)
S3method(.cstr_construct,object.prototype)
S3method(.cstr_construct,octmode)
S3method(.cstr_construct,ordered)
S3method(.cstr_construct,package_version)
S3method(.cstr_construct,pairlist)
S3method(.cstr_construct,person)
S3method(.cstr_construct,quosure)
S3method(.cstr_construct,quosures)
S3method(.cstr_construct,raw)
S3method(.cstr_construct,rel)
S3method(.cstr_construct,rowwise_df)
S3method(.cstr_construct,simpleCondition)
S3method(.cstr_construct,simpleError)
S3method(.cstr_construct,simpleMessage)
S3method(.cstr_construct,simpleUnit)
S3method(.cstr_construct,simpleWarning)
S3method(.cstr_construct,tbl_df)
S3method(.cstr_construct,theme)
S3method(.cstr_construct,ts)
S3method(.cstr_construct,uneval)
S3method(.cstr_construct,vctrs_list_of)
S3method(.cstr_construct,waiver)
S3method(.cstr_construct,warning)
S3method(.cstr_construct,weakref)
S3method(.cstr_construct,xml_document.default)
S3method(.cstr_construct,xts)
S3method(.cstr_construct,yearmon)
S3method(.cstr_construct,yearqtr)
S3method(.cstr_construct,zoo)
S3method(.cstr_construct,zooreg)
S3method(.cstr_construct.AsIs,I)
S3method(.cstr_construct.CoordCartesian,coord_cartesian)
S3method(.cstr_construct.CoordCartesian,environment)
S3method(.cstr_construct.CoordFixed,coord_fixed)
S3method(.cstr_construct.CoordFixed,environment)
S3method(.cstr_construct.CoordFlip,coord_flip)
S3method(.cstr_construct.CoordFlip,environment)
S3method(.cstr_construct.CoordMap,coord_map)
S3method(.cstr_construct.CoordMap,environment)
S3method(.cstr_construct.CoordMunch,coord_munch)
S3method(.cstr_construct.CoordMunch,environment)
S3method(.cstr_construct.CoordPolar,coord_polar)
S3method(.cstr_construct.CoordPolar,environment)
S3method(.cstr_construct.CoordQuickmap,coord_quickmap)
S3method(.cstr_construct.CoordQuickmap,environment)
S3method(.cstr_construct.CoordSf,coord_sf)
S3method(.cstr_construct.CoordSf,environment)
S3method(.cstr_construct.CoordTrans,coord_trans)
S3method(.cstr_construct.CoordTrans,environment)
S3method(.cstr_construct.Date,as.Date)
S3method(.cstr_construct.Date,as_date)
S3method(.cstr_construct.Date,as_date.numeric)
S3method(.cstr_construct.Date,date)
S3method(.cstr_construct.Date,double)
S3method(.cstr_construct.Date,new_date)
S3method(.cstr_construct.Date.as.Date,numeric)
S3method(.cstr_construct.FacetGrid,environment)
S3method(.cstr_construct.FacetGrid,facet_grid)
S3method(.cstr_construct.FacetGrid,ggproto)
S3method(.cstr_construct.FacetWrap,environment)
S3method(.cstr_construct.FacetWrap,facet_wrap)
S3method(.cstr_construct.FacetWrap,ggproto)
S3method(.cstr_construct.Guide,default)
S3method(.cstr_construct.Guide,environment)
S3method(.cstr_construct.Layer,default)
S3method(.cstr_construct.Layer,environment)
S3method(.cstr_construct.Layer,layer)
S3method(.cstr_construct.NULL,"NULL")
S3method(.cstr_construct.POSIXct,.POSIXct)
S3method(.cstr_construct.POSIXct,as.POSIXct)
S3method(.cstr_construct.POSIXct,as.POSIXct.numeric)
S3method(.cstr_construct.POSIXct,as_datetime)
S3method(.cstr_construct.POSIXct,as_datetime.numeric)
S3method(.cstr_construct.POSIXct,atomic)
S3method(.cstr_construct.POSIXlt,as.POSIXlt)
S3method(.cstr_construct.POSIXlt,list)
S3method(.cstr_construct.R_system_version,R_system_version)
S3method(.cstr_construct.R_system_version,list)
S3method(.cstr_construct.S4,new)
S3method(.cstr_construct.Scale,default)
S3method(.cstr_construct.Scale,environment)
S3method(.cstr_construct.ScalesList,ScalesList)
S3method(.cstr_construct.ScalesList,environment)
S3method(.cstr_construct.array,array)
S3method(.cstr_construct.bibentry,bibentry)
S3method(.cstr_construct.blob,as_blob)
S3method(.cstr_construct.blob,blob)
S3method(.cstr_construct.blob,new_blob)
S3method(.cstr_construct.character,default)
S3method(.cstr_construct.citationFooter,citFooter)
S3method(.cstr_construct.citationHeader,citHeader)
S3method(.cstr_construct.classGeneratorFunction,setClass)
S3method(.cstr_construct.classPrototypeDef,prototype)
S3method(.cstr_construct.classRepresentation,getClassDef)
S3method(.cstr_construct.complex,default)
S3method(.cstr_construct.constructive_options,opts)
S3method(.cstr_construct.data.frame,data.frame)
S3method(.cstr_construct.data.frame,list)
S3method(.cstr_construct.data.frame,read.table)
S3method(.cstr_construct.data.table,data.table)
S3method(.cstr_construct.data.table,list)
S3method(.cstr_construct.difftime,as.difftime)
S3method(.cstr_construct.dm,dm)
S3method(.cstr_construct.dm,list)
S3method(.cstr_construct.dots,default)
S3method(.cstr_construct.double,default)
S3method(.cstr_construct.element_blank,element_blank)
S3method(.cstr_construct.element_blank,list)
S3method(.cstr_construct.element_grob,element_grob)
S3method(.cstr_construct.element_grob,list)
S3method(.cstr_construct.element_line,element_line)
S3method(.cstr_construct.element_line,list)
S3method(.cstr_construct.element_rect,element_rect)
S3method(.cstr_construct.element_rect,list)
S3method(.cstr_construct.element_render,element_render)
S3method(.cstr_construct.element_render,list)
S3method(.cstr_construct.element_text,element_text)
S3method(.cstr_construct.element_text,list)
S3method(.cstr_construct.environment,.env)
S3method(.cstr_construct.environment,as.environment)
S3method(.cstr_construct.environment,list2env)
S3method(.cstr_construct.environment,new.env)
S3method(.cstr_construct.environment,new_environment)
S3method(.cstr_construct.environment,predefine)
S3method(.cstr_construct.environment,topenv)
S3method(.cstr_construct.error,errorCondition)
S3method(.cstr_construct.expression,default)
S3method(.cstr_construct.externalptr,default)
S3method(.cstr_construct.factor,as_factor)
S3method(.cstr_construct.factor,factor)
S3method(.cstr_construct.factor,integer)
S3method(.cstr_construct.factor,new_factor)
S3method(.cstr_construct.formula,as.formula)
S3method(.cstr_construct.formula,default)
S3method(.cstr_construct.formula,formula)
S3method(.cstr_construct.formula,new_formula)
S3method(.cstr_construct.function,"function")
S3method(.cstr_construct.function,as.function)
S3method(.cstr_construct.function,new_function)
S3method(.cstr_construct.ggplot,ggplot)
S3method(.cstr_construct.ggplot,list)
S3method(.cstr_construct.ggproto,default)
S3method(.cstr_construct.ggproto,environment)
S3method(.cstr_construct.ggproto,ggproto)
S3method(.cstr_construct.grouped_df,default)
S3method(.cstr_construct.grouped_df,list)
S3method(.cstr_construct.hexmode,as.hexmode)
S3method(.cstr_construct.integer,default)
S3method(.cstr_construct.integer64,as.integer64)
S3method(.cstr_construct.integer64,double)
S3method(.cstr_construct.labels,labs)
S3method(.cstr_construct.labels,list)
S3method(.cstr_construct.language,default)
S3method(.cstr_construct.list,list)
S3method(.cstr_construct.list,list2)
S3method(.cstr_construct.logical,default)
S3method(.cstr_construct.margin,double)
S3method(.cstr_construct.margin,margin)
S3method(.cstr_construct.matrix,array)
S3method(.cstr_construct.matrix,cbind)
S3method(.cstr_construct.matrix,matrix)
S3method(.cstr_construct.matrix,rbind)
S3method(.cstr_construct.mts,atomic)
S3method(.cstr_construct.mts,ts)
S3method(.cstr_construct.noquote,noquote)
S3method(.cstr_construct.numeric_version,list)
S3method(.cstr_construct.numeric_version,numeric_version)
S3method(.cstr_construct.octmode,as.octmode)
S3method(.cstr_construct.ordered,factor)
S3method(.cstr_construct.ordered,integer)
S3method(.cstr_construct.ordered,new_ordered)
S3method(.cstr_construct.ordered,ordered)
S3method(.cstr_construct.package_version,list)
S3method(.cstr_construct.package_version,package_version)
S3method(.cstr_construct.pairlist,pairlist)
S3method(.cstr_construct.pairlist,pairlist2)
S3method(.cstr_construct.person,person)
S3method(.cstr_construct.quosure,language)
S3method(.cstr_construct.quosure,new_quosure)
S3method(.cstr_construct.quosures,list)
S3method(.cstr_construct.quosures,new_quosures)
S3method(.cstr_construct.raw,as.raw)
S3method(.cstr_construct.raw,charToRaw)
S3method(.cstr_construct.rel,double)
S3method(.cstr_construct.rel,rel)
S3method(.cstr_construct.rowwise_df,default)
S3method(.cstr_construct.rowwise_df,list)
S3method(.cstr_construct.simpleCondition,simpleCondition)
S3method(.cstr_construct.simpleError,simpleError)
S3method(.cstr_construct.simpleMessage,simpleMessage)
S3method(.cstr_construct.simpleUnit,double)
S3method(.cstr_construct.simpleUnit,unit)
S3method(.cstr_construct.simpleWarning,simpleWarning)
S3method(.cstr_construct.tbl_df,list)
S3method(.cstr_construct.tbl_df,tibble)
S3method(.cstr_construct.tbl_df,tribble)
S3method(.cstr_construct.theme,list)
S3method(.cstr_construct.theme,theme)
S3method(.cstr_construct.ts,atomic)
S3method(.cstr_construct.ts,ts)
S3method(.cstr_construct.uneval,aes)
S3method(.cstr_construct.uneval,list)
S3method(.cstr_construct.vctrs_list_of,list)
S3method(.cstr_construct.vctrs_list_of,list_of)
S3method(.cstr_construct.waiver,list)
S3method(.cstr_construct.waiver,waiver)
S3method(.cstr_construct.warning,warningCondition)
S3method(.cstr_construct.weakref,new_weakref)
S3method(.cstr_construct.xts,.xts)
S3method(.cstr_construct.xts,as.xts.data.frame)
S3method(.cstr_construct.xts,as.xts.matrix)
S3method(.cstr_construct.xts,xts)
S3method(.cstr_construct.yearmon,as.yearmon)
S3method(.cstr_construct.yearmon,yearmon)
S3method(.cstr_construct.yearqtr,as.yearqtr)
S3method(.cstr_construct.yearqtr,yearqtr)
S3method(.cstr_construct.zoo,zoo)
S3method(.cstr_construct.zooreg,zooreg)
S3method(`.cstr_construct.ggplot2::mapping`,aes)
S3method(`.cstr_construct.ggplot2::mapping`,list)
S3method(constructive::.cstr_construct,CoordRadial)
S3method(constructive::.cstr_construct,CoordTransform)
S3method(constructive::.cstr_construct,FacetNull)
S3method(constructive::.cstr_construct,GuideAxis)
S3method(constructive::.cstr_construct,GuideAxisLogticks)
S3method(constructive::.cstr_construct,GuideAxisStack)
S3method(constructive::.cstr_construct,GuideAxisTheta)
S3method(constructive::.cstr_construct,GuideBins)
S3method(constructive::.cstr_construct,GuideColourbar)
S3method(constructive::.cstr_construct,GuideColoursteps)
S3method(constructive::.cstr_construct,GuideCustom)
S3method(constructive::.cstr_construct,GuideLegend)
S3method(constructive::.cstr_construct,GuideNone)
S3method(constructive::.cstr_construct,Guides)
S3method(constructive::.cstr_construct,R6)
S3method(constructive::.cstr_construct,R6ClassGenerator)
S3method(constructive::.cstr_construct,S7_S3_class)
S3method(constructive::.cstr_construct,S7_any)
S3method(constructive::.cstr_construct,S7_base_class)
S3method(constructive::.cstr_construct,S7_class)
S3method(constructive::.cstr_construct,S7_external_generic)
S3method(constructive::.cstr_construct,S7_generic)
S3method(constructive::.cstr_construct,S7_object)
S3method(constructive::.cstr_construct,S7_property)
S3method(constructive::.cstr_construct,S7_union)
S3method(constructive::.cstr_construct,ellmer::TypeArray)
S3method(constructive::.cstr_construct,ellmer::TypeBasic)
S3method(constructive::.cstr_construct,ellmer::TypeEnum)
S3method(constructive::.cstr_construct,ellmer::TypeJsonSchema)
S3method(constructive::.cstr_construct,ellmer::TypeObject)
S3method(constructive::.cstr_construct,ggplot2::labels)
S3method(constructive::.cstr_construct,object)
S3method(constructive::.cstr_construct,xml_document)
S3method(format,rd_section_enumerateOptFunctions)
S3method(print,constructive)
S3method(print,constructive_code)
S3method(print,constructive_options)
export(.cstr_apply)
export(.cstr_combine_errors)
export(.cstr_construct)
export(.cstr_new_class)
export(.cstr_new_constructor)
export(.cstr_options)
export(.cstr_pipe)
export(.cstr_repair_attributes)
export(.cstr_wrap)
export(.env)
export(.xptr)
export(compare_options)
export(construct)
export(construct_base)
export(construct_clip)
export(construct_diff)
export(construct_dput)
export(construct_dump)
export(construct_issues)
export(construct_multi)
export(construct_reprex)
export(construct_signature)
export(deparse_call)
export(opts_AsIs)
export(opts_CoordCartesian)
export(opts_CoordFixed)
export(opts_CoordFlip)
export(opts_CoordMap)
export(opts_CoordMunch)
export(opts_CoordPolar)
export(opts_CoordQuickmap)
export(opts_CoordRadial)
export(opts_CoordSf)
export(opts_CoordTrans)
export(opts_CoordTransform)
export(opts_Date)
export(opts_FacetGrid)
export(opts_FacetNull)
export(opts_FacetWrap)
export(opts_Guide)
export(opts_GuideAxis)
export(opts_GuideAxisLogticks)
export(opts_GuideAxisStack)
export(opts_GuideAxisTheta)
export(opts_GuideBins)
export(opts_GuideColourbar)
export(opts_GuideColoursteps)
export(opts_GuideCustom)
export(opts_GuideLegend)
export(opts_GuideNone)
export(opts_Guides)
export(opts_Layer)
export(opts_NULL)
export(opts_POSIXct)
export(opts_POSIXlt)
export(opts_R6)
export(opts_R6ClassGenerator)
export(opts_R_system_version)
export(opts_S4)
export(opts_S7_S3_class)
export(opts_S7_any)
export(opts_S7_base_class)
export(opts_S7_class)
export(opts_S7_external_generic)
export(opts_S7_generic)
export(opts_S7_object)
export(opts_S7_property)
export(opts_S7_union)
export(opts_Scale)
export(opts_ScalesList)
export(opts_array)
export(opts_atomic)
export(opts_bibentry)
export(opts_blob)
export(opts_character)
export(opts_citationFooter)
export(opts_citationHeader)
export(opts_classGeneratorFunction)
export(opts_classPrototypeDef)
export(opts_classRepresentation)
export(opts_complex)
export(opts_constructive_options)
export(opts_data.frame)
export(opts_data.table)
export(opts_difftime)
export(opts_dm)
export(opts_dots)
export(opts_double)
export(opts_element_blank)
export(opts_element_grob)
export(opts_element_line)
export(opts_element_rect)
export(opts_element_render)
export(opts_element_text)
export(opts_ellmer_TypeArray)
export(opts_ellmer_TypeBasic)
export(opts_ellmer_TypeEnum)
export(opts_ellmer_TypeJsonSchema)
export(opts_ellmer_TypeObject)
export(opts_environment)
export(opts_error)
export(opts_expression)
export(opts_externalptr)
export(opts_factor)
export(opts_formula)
export(opts_function)
export(opts_ggplot)
export(opts_ggplot2_element_blank)
export(opts_ggplot2_element_geom)
export(opts_ggplot2_element_line)
export(opts_ggplot2_element_point)
export(opts_ggplot2_element_polygon)
export(opts_ggplot2_element_rect)
export(opts_ggplot2_element_text)
export(opts_ggplot2_ggplot)
export(opts_ggplot2_labels)
export(opts_ggplot2_mapping)
export(opts_ggplot2_margin)
export(opts_ggplot2_theme)
export(opts_ggproto)
export(opts_grouped_df)
export(opts_hexmode)
export(opts_integer)
export(opts_integer64)
export(opts_labels)
export(opts_language)
export(opts_list)
export(opts_logical)
export(opts_margin)
export(opts_matrix)
export(opts_mts)
export(opts_noquote)
export(opts_numeric_version)
export(opts_object)
export(opts_octmode)
export(opts_ordered)
export(opts_package_version)
export(opts_pairlist)
export(opts_person)
export(opts_quosure)
export(opts_quosures)
export(opts_raw)
export(opts_rel)
export(opts_rowwise_df)
export(opts_simpleCondition)
export(opts_simpleError)
export(opts_simpleMessage)
export(opts_simpleUnit)
export(opts_simpleWarning)
export(opts_tbl_df)
export(opts_theme)
export(opts_ts)
export(opts_uneval)
export(opts_vctrs_list_of)
export(opts_waiver)
export(opts_warning)
export(opts_weakref)
export(opts_xml_document)
export(opts_xts)
export(opts_yearmon)
export(opts_yearqtr)
export(opts_zoo)
export(opts_zooreg)
import(rlang)
importFrom(grDevices,dev.off)
importFrom(grDevices,pdf)
importFrom(methods,getSlots)
importFrom(stats,setNames)
importFrom(utils,capture.output)
importFrom(utils,getFromNamespace)
importFrom(utils,head)
importFrom(utils,methods)
importFrom(utils,packageDescription)
importFrom(utils,tail)
useDynLib("")
useDynLib(constructive)
