#' Custom constructors
#'
#' We export a collection of functions that can be used to design custom methods for
#' `.cstr_construct()` or custom constructors for a given method.
#'
#' * `.cstr_construct` : Low level generic for object construction code generation
#' * `.cstr_repair_attributes` : Helper to repair attributes of objects
#' * `.cstr_options` : Define and check options to pass to custom constructors
#' * `.cstr_fetch_opts`
#' * `.cstr_apply`
#' * `.cstr_wrap`
#' * `.cstr_pipe`
#' * `.cstr_combine_errors`
#' @name custom-constructors
NULL
