# structure corner cases

    Code
      construct(a)
    Output
      c(name2 = 1) |>
        structure(levels = "label2") |>
        (`attr<-`)(".Names", "name1") |>
        (`attr<-`)(".Label", "label1")

