# theme

    Code
      construct(ggplot2::theme_bw())
    Output
      ggplot2::theme_bw()
    Code
      construct(ggplot2::theme_bw(base_size = 11, base_line_size = 0.5))
    Output
      ggplot2::theme_bw()
    Code
      construct(ggplot2::theme_bw(base_size = 22, base_line_size = 0.5))
    Output
      ggplot2::theme_bw(base_size = 22, base_line_size = 0.5)
    Code
      construct(ggplot2::theme_bw(base_size = 11, base_line_size = 1))
    Output
      ggplot2::theme_bw(base_line_size = 1)
    Code
      construct(ggplot2::theme_bw(base_size = 22, base_line_size = 1))
    Output
      ggplot2::theme_bw(base_size = 22)
    Code
      construct(ggplot2::theme())
    Output
      ggplot2::theme()
    Code
      construct(ggplot2::theme(axis.title = "foo"))
    Output
      ggplot2::theme(axis.title = "foo")

