# pairlist

    Code
      construct(pairlist(a = 1, 2))
    Output
      pairlist(a = 1, 2)
    Code
      construct(pairlist(a = 1, 2), opts_pairlist("pairlist2"))
    Output
      rlang::pairlist2(a = 1, 2)

