# construct_signature

    Code
      construct_signature(transform)
    Output
      transform(`_data`, ...)
    Code
      construct_signature(lm)
    Output
      lm(formula, data, subset, weights, na.action, method = "qr", model = TRUE, x = FALSE, y = FALSE, qr = TRUE, singular.ok = TRUE, contrasts = NULL, offset, ...)

