# weakref

    Code
      construct(rlang::new_weakref(.GlobalEnv))
    Output
      rlang::new_weakref(.GlobalEnv)
    Code
      construct(rlang::new_weakref(.GlobalEnv, value = 1))
    Output
      rlang::new_weakref(.GlobalEnv, value = 1)

