% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/construct_dump.R
\name{construct_dump}
\alias{construct_dump}
\title{Dump Constructed Code to a File}
\usage{
construct_dump(x, path, append = FALSE, ...)
}
\arguments{
\item{x}{A named list or an environment.}

\item{path}{File or connection to write to.}

\item{append}{If FALSE, will overwrite existing file. If TRUE, will append to existing file. In both cases, if the file does not exist a new file is created.}

\item{...}{Forwarded to \code{construct_multi()}}
}
\value{
Returns \code{NULL} invisibly, called for side effects.
}
\description{
An alternative to \code{base::dump()} using code built with \pkg{constructive}.
}
