% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/global-options.R
\name{constructive-global_options}
\alias{constructive-global_options}
\alias{constructive_opts_template}
\alias{constructive_pretty}
\alias{constructive_print_mode}
\title{Global Options}
\description{
Set these options to tweak \{constructive\}'s global behavior, to set them
permanently you can edit your \code{.RProfile} (\code{usethis::edit_r_profile()} might help).
}
\details{
\itemize{
\item Set \verb{options(constructive_print_mode = <character>)} to change the default
value of the \code{print_mode} arument, of \code{print.constructive}, where \verb{<character>} is a vector
of strings among the following :
\itemize{
\item \code{"console"} : The default behavior, the code is printed in the console
\item \code{"script"} : The code is copied to a new R script
\item \code{"reprex"} : The code is shown in the viewer as a reprex,
the reprex (not only the code!) is also copied to the clipboard. Note that
if the construction fails the reprex will too, and it might happen often
when constructing environments since \pkg{reprex} opens a new session.
\item \code{"clipboard"} : The constructed code is copied to the clipboard, if combined
with \code{"reprex"} this takes precedence
}
\item Set \verb{options(constructive_opts_template = <list>)} to set default constructive options,
see documentation of the \code{template} arg in \code{?construct}
\item Set \code{options(constructive_pretty = FALSE)} to disable pretty printinh using
\{prettycode\}
}
}
