% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/s3-pairlist.R
\name{opts_pairlist}
\alias{opts_pairlist}
\title{Constructive options for pairlists}
\usage{
opts_pairlist(constructor = c("pairlist", "pairlist2"), ...)
}
\arguments{
\item{constructor}{String. Name of the function used to construct the environment, see Details section.}

\item{...}{Should not be used. Forces passing arguments by name.}
}
\value{
An object of class <constructive_options/constructive_options_factor>
}
\description{
Depending on \code{constructor}, we construct the environment as follows:
\itemize{
\item \code{"pairlist"} (default): Build the object using a \code{pairlist()} call.
\item \code{"pairlist2"} : Build the object using a \code{rlang::pairlist2()} call.
}
}
