% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/register_constructors.R
\name{.cstr_register_constructors}
\alias{.cstr_register_constructors}
\title{Register constructors}
\usage{
.cstr_register_constructors(class, ...)
}
\arguments{
\item{class}{A string}

\item{...}{named constructors}
}
\value{
Returns \code{NULL} invisibly, called for side effects.
}
\description{
Use this function to register a custom constructor. See vignette for more information.
}
