% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/s3-language.R
\name{opts_language}
\alias{opts_language}
\title{Constructive options for type 'language'}
\usage{
opts_language(constructor = c("default"), ...)
}
\arguments{
\item{constructor}{String. Name of the function used to construct the environment.}

\item{...}{Should not be used. Forces passing arguments by name.}
}
\value{
An object of class <constructive_options/constructive_options_environment>
}
\description{
These options will be used on objects of type 'language'. By default this
function is useless as nothing can be set, this is provided in case users want
to extend the method with other constructors.
}
\details{
Depending on \code{constructor}, we construct the environment as follows:
\itemize{
\item \code{"default"} : We use constructive's deparsing algorithm on attributeless calls,
and use \code{as.call()} on other language elements when attributes need to be constructed.
}
}
