% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/s3-vctrs_list_of.R
\name{opts_vctrs_list_of}
\alias{opts_vctrs_list_of}
\title{Constructive options for class 'data.table'}
\usage{
opts_vctrs_list_of(constructor = c("list_of", "list"), ...)
}
\arguments{
\item{constructor}{String. Name of the function used to construct the environment, see Details section.}

\item{...}{Should not be used. Forces passing arguments by name.}
}
\value{
An object of class <constructive_options/constructive_options_data.table>
}
\description{
These options will be used on objects of class 'data.table'.
}
\details{
Depending on \code{constructor}, we construct the object as follows:
\itemize{
\item \code{"list_of"} (default): Wrap the column definitions in a \code{list_of()} call.
\item \code{"list"} : Use \code{list()} and treat the class as a regular attribute.
}
}
