% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/s4-classPrototypeDef.R
\name{opts_classPrototypeDef}
\alias{opts_classPrototypeDef}
\title{Constructive options for class 'classPrototypeDef'}
\usage{
opts_classPrototypeDef(constructor = c("prototype"), ...)
}
\arguments{
\item{constructor}{String. Name of the function used to construct the object, see Details section.}

\item{...}{Should not be used. Forces passing arguments by name.}
}
\value{
An object of class <constructive_options/constructive_options_classPrototypeDef>
}
\description{
These options will be used on objects of class 'classPrototypeDef'.
}
