% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/environment_utils.R
\name{.env}
\alias{.env}
\title{Fetch environment from memory address}
\usage{
.env(address, parents = NULL, ...)
}
\arguments{
\item{address}{Memory address of the environment}

\item{parents, ...}{ignored}
}
\value{
The environment that the memory address points to.
}
\description{
This is designed to be used in constructed output. The \code{parents} and \code{...} arguments
are not processed and only used to display additional information. If used on
an improper memory address the output might be erratic or the session might crash.
}
