% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/opts.R
\name{.cstr_options}
\alias{.cstr_options}
\title{Create constructive options}
\usage{
.cstr_options(class, ...)
}
\arguments{
\item{class}{A string. An S3 class.}

\item{...}{Options to set}
}
\value{
An object of class \code{c(paste0("constructive_options_", class), "constructive_options")}
}
\description{
Exported for custom constructor design.
}
