% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/construct-helpers.R
\name{.cstr_construct}
\alias{.cstr_construct}
\title{Generic for object code generation}
\usage{
.cstr_construct(x, ..., data = NULL)
}
\arguments{
\item{x}{An object, for \code{construct_multi()} a named list or an environment.}

\item{...}{Constructive options built with the \verb{opts_*()} family of functions. See the "Constructive options"
section below.}

\item{data}{Named list or environment of objects we want to detect and mention by name (as opposed to
deparsing them further). Can also contain unnamed nested lists, environments, or
package names, in the latter case package exports and datasets will be considered.
In case of conflict, the last provided name is considered.}
}
\value{
A character vector
}
\description{
Exported for custom constructor design. \code{.cstr_construct()} is basically a
naked \code{construct()}, without the checks, the style, the object post processing etc...
}
