% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/s3-rowwise_df.R
\name{opts_rowwise_df}
\alias{opts_rowwise_df}
\title{Constructive options for class 'rowwise_df'}
\usage{
opts_rowwise_df(constructor = c("default", "next", "list"), ...)
}
\arguments{
\item{constructor}{String. Name of the function used to construct the environment, see Details section.}

\item{...}{Should not be used. Forces passing arguments by name.}
}
\value{
An object of class <constructive_options/constructive_options_factor>
}
\description{
These options will be used on objects of class 'rowwise_df'.
}
\details{
Depending on \code{constructor}, we construct the environment as follows:
\itemize{
\item \code{"next"} : Use the constructor for the next supported class. Call \code{.class2()}
on the object to see in which order the methods will be tried.
\item \code{"list"} : We define as an list object and repair attributes.
}
}
