% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/constructive-package.R
\docType{package}
\name{constructive-package}
\alias{constructive}
\alias{constructive-package}
\title{constructive: Display Idiomatic Code to Construct Most R Objects}
\description{
Prints code that can be used to recreate R objects. In a sense it is similar to 'base::dput()' or 'base::deparse()' but 'constructive' strives to use idiomatic constructors.
}
\seealso{
Useful links:
\itemize{
  \item \url{https://github.com/cynkra/constructive}
  \item \url{https://cynkra.github.io/constructive/}
  \item Report bugs at \url{https://github.com/cynkra/constructive/issues}
}

}
\author{
\strong{Maintainer}: Antoine Fabri \email{antoine.fabri@gmail.com}

Other contributors:
\itemize{
  \item Kirill Müller \email{kirill@cynkra.com} (\href{https://orcid.org/0000-0002-1416-3412}{ORCID}) [contributor]
}

}
\keyword{internal}
