% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/s3-AsIs.R
\name{opts_AsIs}
\alias{opts_AsIs}
\title{Constructive options for the class \code{AsIs}}
\usage{
opts_AsIs(constructor = c("I", "next", "atomic"), ...)
}
\arguments{
\item{constructor}{String. Name of the function used to construct the environment, see Details section.}

\item{...}{Should not be used. Forces passing arguments by name.}
}
\value{
An object of class <constructive_options/constructive_options_array>
}
\description{
These options will be used on objects of class \code{AsIs}. \code{AsIs} objects are
created with \code{I()} which only prepends \code{"AsIs"} to the class attribute.
}
\details{
Depending on \code{constructor}, we construct the object as follows:
\itemize{
\item \code{"I"} (default): Use the \code{I()} function
\item \code{"next"} : Use the constructor for the next supported class. Call \code{.class2()}
on the object to see in which order the methods will be tried.
\item \code{"atomic"} : We define as an atomic vector and repair attributes
}
}
