% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/s4.R
\name{opts_S4}
\alias{opts_S4}
\title{Constructive options for class 'S4'}
\usage{
opts_S4(constructor = c("new"), ...)
}
\arguments{
\item{constructor}{String. Name of the function used to construct the environment, see Details section.}

\item{...}{Should not be used. Forces passing arguments by name.}
}
\value{
An object of class <constructive_options/constructive_options_S4>
}
\description{
These options will be used on objects of class 'S4'. Note that the support
for S4 is very experimental so might easily beak. Please report issues if it
does.
}
