% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/repair_attributes.R
\docType{data}
\name{constructors}
\alias{constructors}
\title{constructors}
\format{
An object of class \code{environment} of length 36.
}
\usage{
constructors
}
\description{
A nested environment containing constructor functions for the package \pkg{constructive}
}
\keyword{datasets}
