% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/s4-classGeneratorFunction.R
\name{opts_classGeneratorFunction}
\alias{opts_classGeneratorFunction}
\title{Constructive options for class 'classGeneratorFunction'}
\usage{
opts_classGeneratorFunction(constructor = c("setClass"), ...)
}
\arguments{
\item{constructor}{String. Name of the function used to construct the object.}

\item{...}{Should not be used. Forces passing arguments by name.}
}
\value{
An object of class <constructive_options/constructive_options_classGeneratorFunction>
}
\description{
These options will be used on objects of class 'classGeneratorFunction'.
}
