% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/s3-dm.R
\name{opts_dm}
\alias{opts_dm}
\title{Constructive options class 'dm'}
\usage{
opts_dm(constructor = c("dm", "next", "list"), ...)
}
\arguments{
\item{constructor}{String. Name of the function used to construct the environment.}

\item{...}{Should not be used. Forces passing arguments by name.}
}
\value{
An object of class <constructive_options/constructive_options_environment>
}
\description{
These options will be used on objects of class 'dm'.
}
\details{
Depending on \code{constructor}, we construct the environment as follows:
\itemize{
\item \code{"dm"} (default): We use \code{dm::dm()} and other functions from \pkg{dm} to adjust the content.
\item \code{"next"} : Use the constructor for the next supported class. Call \code{.class2()}
on the object to see in which order the methods will be tried.
\item \code{"list"} : Use \code{list()} and treat the class as a regular attribute.
}
}
