% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/C_wrappers.R
\name{.xptr}
\alias{.xptr}
\title{Build a pointer from a memory address}
\usage{
.xptr(address)
}
\arguments{
\item{address}{Memory address}
}
\value{
The external pointer (type "externalptr") that the memory address points to.
}
\description{
Base R doesn't provide utilities to build or manipulate external pointers
(objects of type "externalptr"), so we provide our own. Be warned that
objects defined with \code{.xptr()} are not stable across sessions,
however this is the best we can
}
