% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/construct_issues.R
\name{construct_issues}
\alias{construct_issues}
\title{Show constructive issues}
\usage{
construct_issues(x = NULL)
}
\arguments{
\item{x}{An object built by \code{construct()}, if \code{NULL} the latest encountered
issues will be displayed}
}
\value{
A character vector with class "waldo_compare"
}
\description{
Show constructive issues
}
