% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/custom_constructors.R
\name{custom-constructors}
\alias{custom-constructors}
\title{Custom constructors}
\description{
We export a collection of functions that can be used to design custom methods for
\code{.cstr_construct()} or custom constructors for a given method.
}
\details{
\itemize{
\item \code{.cstr_construct} : Low level generic for object construction code generation
\item \code{.cstr_repair_attributes} : Helper to repair attributes of objects
\item \code{.cstr_options} : Define and check options to pass to custom constructors
\item \code{.cstr_fetch_opts}
\item \code{.cstr_apply}
\item \code{.cstr_wrap}
\item \code{.cstr_pipe}
\item \code{.cstr_combine_errors}
}
}
