% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{.cstr_wrap}
\alias{.cstr_wrap}
\title{Wrap argument code in function call}
\usage{
.cstr_wrap(args, fun, new_line = FALSE)
}
\arguments{
\item{args}{A character vector containing the code of arguments.}

\item{fun}{A string. The name of the function to use in the function call.
Use \code{fun = ""} to wrap in parentheses.}

\item{new_line}{Boolean. Whether to insert a new line between \code{"fun("} and the closing \code{")"}.}
}
\value{
A character vector.
}
\description{
Exported for custom constructor design. Generally called through \code{.cstr_apply()}.
}
