% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/construct_signature.R
\name{construct_signature}
\alias{construct_signature}
\title{Construct a function's signature}
\usage{
construct_signature(x, name = NULL, one_liner = FALSE, style = TRUE)
}
\arguments{
\item{x}{A function}

\item{name}{The name of the function, by default we use the symbol provided to \code{x}}

\item{one_liner}{Boolean. Whether to collapse multi-line expressions on a single line using
semicolons}

\item{style}{Boolean. Whether to give a class "constructive_code" on the output
for pretty printing.}
}
\value{
a string or a character vector, with a class "constructive_code" for pretty
printing if \code{style} is \code{TRUE}
}
\description{
Construct a function's signature
}
\examples{
construct_signature(lm)
}
